@@ -12,12 +12,12 @@ with arrays that contain numbers with uncertainties.
 
 - Arrays of numbers with uncertainties can be built as follows:
 
-  arr = unumpy.uarray(([1, 2], [0.01, 0.002]))  # (values, uncertainties)
+  arr = unumpy.uarray([1, 2], [0.01, 0.002])  # (values, uncertainties)
 
 NumPy arrays of numbers with uncertainties can also be built directly
 through NumPy, thanks to NumPy's support of arrays of arbitrary objects:
 
-  arr = numpy.array([uncertainties.ufloat((1, 0.1)),...])
+  arr = numpy.array([uncertainties.ufloat(1, 0.1),...])
   
 - Matrices of numbers with uncertainties are best created in one of
 two ways:
@@ -60,7 +60,7 @@ documentation for this module).
 
 This module requires the NumPy package.
 
-(c) 2009-2010 by Eric O. LEBIGOT (EOL) <eric.lebigot@normalesup.org>.
+(c) 2009-2013 by Eric O. LEBIGOT (EOL) <eric.lebigot@normalesup.org>.
 Please send feature requests, bug reports, or feedback to this address.
 
 This software is released under a dual license.  (1) The BSD license.
@@ -69,8 +69,8 @@ author."""
 
 # Local modules:
 from core import *
-from . import core
-from . import ulinalg  # Local sub-module
+from uncertainties.unumpy import core
+from uncertainties.unumpy import ulinalg  # Local sub-module
 
 from uncertainties import __author__
 
